Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMorris Jobke <hey@morrisjobke.de>2020-08-19 18:54:00 +0300
committerMorris Jobke <hey@morrisjobke.de>2020-08-19 19:16:35 +0300
commitfedf9c69d9c84fc0399badef39ed765de72c08f1 (patch)
treebfaae1e7efb907cb236769fada35a9cd05ebf29e /lib/public/IUserSession.php
parent60be722ee8781d9e94ecc66d62c0e5fcb7e3934e (diff)
Use matching parameter names form interfaces and implementations
Found by Psalm 3.14.1 Signed-off-by: Morris Jobke <hey@morrisjobke.de>
Diffstat (limited to 'lib/public/IUserSession.php')
-rw-r--r--lib/public/IUserSession.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/public/IUserSession.php b/lib/public/IUserSession.php
index d71cde72b30..17c751127fa 100644
--- a/lib/public/IUserSession.php
+++ b/lib/public/IUserSession.php
@@ -46,12 +46,12 @@ interface IUserSession {
/**
* Do a user login
*
* @param string $user the username
* @param string $password the password
* @return bool true if successful
* @since 6.0.0
*/
- public function login($user, $password);
+ public function login($uid, $password);
/**
* Logs the user out including all the session data
@@ -46,12 +46,12 @@ interface IUserSession {
* Do a user login
*
- * @param string $user the username
+ * @param string $uid the username
* @param string $password the password
* @return bool true if successful